unit CS_Conv;
  {Code Page transfer Unit - Important only for Czech Language}

  {Unit generujici ruzne prevodni tabulky, tykajici se kodovani cestiny}

interface

type
  tConvertTable=array[#0..#255] of Char;
     {typ prevodni tabulky pro znaky:
     Index = puvodni znak
     Obsah = znak na ktery mam prekodovat}
  tCode=(Latin2,Win1250,Kamenicky,USA);  {kody cestiny + necesky kod - USA}
  tCSCode=Latin2..Kamenicky;
  tDiakr=array[1..2] of string[15];
const
  DiakrLatin2   :tDiakr=('Ԃء眣','Ґ');
  DiakrKamenicky:tDiakr=('','');
  DiakrWin1250  :tDiakr=('','؊ݎ');
  DiakrUSA      :tDiakr=('acdeeinorstuuyz','ACDEEINORSTUUYZ');
   {vsechny ceske znaky s diakritikou ve dvou ceskych a kodech a jejich
   ekvivalenty bez diakritiky v kodu ACSII (USA)
   - z techto konstant se generuji vsechny tabulky}

procedure GetUpCaseTable(var Table:tConvertTable;CSCode:tCode);
   {vytvori prevodni tabulku Table pro prevod malych pismen na velka
   v kodu cestiny CSCode}

procedure GetConvertTable(var Table:tConvertTable;Source:tCSCode;Dest:tCode);
   {vytvori prevodni tabulku Table pro prevod ceskeho kodu Source na
   jiny cesky (nebo na USA - ztrata  diakritiky) kod Dest}

implementation


procedure GetUpCaseTable(var Table:tConvertTable;CSCode:tCode);
   {vytvori prevodni tabulku Table pro prevod melych pismen na velka
   v kodu cestiny CSCode}
  var
    I:Char;
    J:Byte;
    Diakr:tDiakr;
  begin
    case CSCode of
      Latin2    : Diakr:=DiakrLatin2;
      Win1250   : Diakr:=DiakrWin1250;
      Kamenicky : Diakr:=DiakrKamenicky;
      USA       : Diakr:=DiakrUSA;
    end;
    for I:=#0 to #255 do
      Table[I]:=UpCase(I);
    for J:=1 to Length(Diakr[1]) do
      Table[Diakr[1,J]]:=Diakr[2,J];
  end;  {GetUpCaseTable}

procedure GetConvertTable(var Table:tConvertTable;Source:tCSCode;Dest:tCode);
   {vytvori prevodni tabulku Table pro prevod ceskeho kodu Source na
   jiny cesky (nebo na USA - ztrata  diakritiky) kod Dest}
  var
    I:Char;
    J:Byte;
    S,D:tDiakr;
  begin
    case Source of
      Latin2    : S:=DiakrLatin2;
      Win1250   : S:=DiakrWin1250;
      Kamenicky : S:=DiakrKamenicky;
    end;
    case Dest of
      Latin2    : D:=DiakrLatin2;
      Win1250   : D:=DiakrWin1250;
      Kamenicky : D:=DiakrKamenicky;
      USA       : D:=DiakrUSA;
    end;
    for I:=#0 to #255 do
      Table[I]:=I;
    for J:=1 to Length(S[1]) do
      Table[S[1,J]]:=D[1,J];
    for J:=1 to Length(S[2]) do
      Table[S[2,J]]:=D[2,J];
    if (Source=Latin2) and (Dest=Kamenicky) then
      Table[#245]:=#173  {paragraf}
  end;  {GetConvertTable}


begin
end.
